@@ -8,17 +8,31 @@ from .utils.reify import reify
 class Request:
     def __init__(self, url, *args, **kw):
         self.url = url
+        self.callback = kw.pop('callback', None)
 
-class Response(aiohttp.web.Response):
-
-    def __init__(self, url, *args, **kw):
-        body = kw.pop('body', None)
-        super().__init__(*args, **kw)
-
-        if body:
-            self.body = body
+class Response:
+    """
+    wrap an aiohttp.Response with extra functionality
+    but pass any getattr to it
+    """
 
+    def __init__(self, url, response):
         self.url = url
+        self._response = response
+
+    def __getattr__(self, name):
+        return getattr(self._response, name)
+
+    @property
+    def body(self):
+        return self._body
+
+    @property
+    def text(self):
+        if isinstance(self._body, bytes):
+            return self._body.decode('utf-8')
+        else:
+            return self._body
 
     @reify
     def selector(self):
@@ -35,15 +49,3 @@ class Response(aiohttp.web.Response):
         convert possible relative url to absolute based on request url
         """
         return urljoin(self.url, url)
-
-    @staticmethod
-    def _copy_response(url, response):
-        """
-        convert the aiohttp response into our Response type
-        """
-        return Response(
-            url,
-            status=response.status,
-            headers=response.headers,
-            text=response.text,
-        )
